BufferFlags

Struct BufferFlags 

pub struct BufferFlags(/* private fields */);
Buffer flags used to specify buffer usage

Implementations

Source

impl BufferFlags

pub fn is_none(&self) -> bool

Returns true if all bits are zero

pub fn null() -> Self

Creates zeroed bitflag

Source

impl BufferFlags

pub const UNIFORM: Self

Uniform buffers are used to store small amount of data, non indexing

pub const TRANSFER: Self

Transfer buffers are used to read data from it. For example, computation result.

pub const SYNCED: Self

Indicates that the buffer would be synced along the frame